import re

from sphinx_markdown_tables import __version__


def setup(app):
    app.connect('source-read', process_tables)
    return {'version': __version__,
            'parallel_read_safe': True}


def process_tables(app, docname, source):
    """
    Convert markdown tables to html, since recommonmark can't. This requires 3 steps:
        Snip out table sections from the markdown
        Convert them to html
        Replace the old markdown table with an html table

    This function is called by sphinx for each document. `source` is a 1-item list. To update the document, replace
    element 0 in `source`.
    """
    import markdown
    md = markdown.Markdown(extensions=['markdown.extensions.tables'])
    table_processor = markdown.extensions.tables.TableProcessor(md.parser)

    raw_markdown = source[0]
    blocks = re.split(r'(\n{2,})', raw_markdown)

    for i, block in enumerate(blocks):
        if table_processor.test(None, block):
            html = md.convert(block)
            styled = html.replace('<table>', '<table border="1" class="docutils">', 1)  # apply styling
            blocks[i] = styled

    # re-assemble into markdown-with-tables-replaced
    # must replace element 0 for changes to persist
    source[0] = ''.join(blocks)



from setuptools import setup
from codecs import open
from os import path

from sphinx_markdown_tables import __version__

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='sphinx-markdown-tables',
    version=__version__.__version__,
    description='A Sphinx extension for rendering tables written in markdown',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/ryanfox/sphinx-markdown-tables',
    author='Ryan Fox',
    author_email='ryan@foxrow.com',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='sphinx markdown tables',
    packages=['sphinx_markdown_tables'],
    install_requires=['markdown>=3.0.1'],
    data_files=[('', ['LICENSE'])],
    project_urls={
        'Bug Reports': 'https://github.com/ryanfox/sphinx-markdown-tables/issues',
        'Say Thanks!': 'https://foxrow.com',
        'Source': 'https://github.com/ryanfox/sphinx-markdown-tables/',
    },
)
